#
# $Id: RequestArgs.pl,v 33.5 2012/09/26 16:10:15 jettisu Exp $
#
# (c) 1999-2012 Morgan Stanley & Co. Incorporated
# See ..../src/LICENSE for terms of distribution.
#

package MQSeries::Command::MQSC;

%RequestArgs =
  (

   Queue =>
   {
    StorageClass		=> 1,
    QType			=> 1,
    QName			=> 1,
   },

   Channel =>
   {
    ChannelName			=> 1,
    ChannelType			=> 1,
   },

   ChannelStatus =>
   {
    ChannelName			=> 1,
    ChannelInstanceType		=> 1,
    ConnectionName		=> 1,
    XmitQName			=> 1,
   },

   Process =>
   {
    ProcessName			=> 1,
   },

   QueueManager => {},

   Namelist =>
   {
    NamelistName		=> 1,
   },

   ResetQueueStatistics =>
   {
    QName                       => 1,
   },

   SetChlAuthRec =>
   {
    ChlAuth			=> 1,
   },

   InquireChlAuthRecs =>
   {
    ChlAuth			=> 1,
   },

  );

1;
